@@ -1,4 +1,9 @@
 package Text::Snippet::TabStop::Cursor;
+BEGIN {
+  $Text::Snippet::TabStop::Cursor::VERSION = '0.04';
+}
+
+# ABSTRACT: Provides a bi-directional iterator interface for moving from one tab-stop to it's siblings
 
 use strict;
 use warnings;
@@ -6,71 +11,6 @@ use Class::XSAccessor getters => {snippet => 'snippet'};
 use Scalar::Util qw(blessed refaddr);
 use Carp qw(croak);
 
-=head1 NAME
-
-Text::Snippet::TabStop::Cursor - Provides a bi-directional iterator interface for moving from one tab-stop to it's siblings
-
-=head1 CLASS METHODS
-
-=head2 new
-
-=head1 INSTANCE METHODS
-
-=over 4
-
-=item * snippet
-
-Maintains a reference to the snippet that this cursor is iterating over.
-
-=item * has_prev
-
-Returns true/false depending on whether the cursor can move to a previous
-tab stop.
-
-=item * prev
-
-Moves the cursor to the previous tab stop and returns that tab stop.
-You can only iterate one element off the end of the underlying set of
-tab stops.
-
-=item * has_next
-
-Returns true/false depending on whether the cursor can move to a
-subsequent tab stop.
-
-=item * next
-
-Moves the cursor to the next tab stop and returns that tab stop.  You can
-only iterate one element off the end of the underlying set of tab stops.
-
-=item * current
-
-Returns the tab stop the cursor is currently pointing at.  When the cursor
-is first created, this method will always return C<undef> until C<next>
-has been called at least once.
-
-=item * current_position
-
-Returns an ArrayRef reflecting the line/column position relative to
-the beginning of the snippet.  Both numbers are zero-based so a tab
-stop starting on the first line, first character would return a value
-of C<[0,0]>.
-
-=item * current_char_position
-
-Returns an integer reflecting the current cursor position where 0 is the 
-first character of the snippet and each character is counted up until
-the current position of the cursor.
-
-=item * is_terminal
-
-Returns true if this tab stop is a "terminal" tab stop (i.e. once the
-user iterates to this tab stop, the iterator should be restored and
-normal editing should resume).
-
-=back
-
-=cut
 
 sub new {
 	my $class = shift;
@@ -159,3 +99,88 @@ sub is_terminal {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Text::Snippet::TabStop::Cursor - Provides a bi-directional iterator interface for moving from one tab-stop to it's siblings
+
+=head1 VERSION
+
+version 0.04
+
+=head1 CLASS METHODS
+
+=head2 new
+
+=head1 INSTANCE METHODS
+
+=over 4
+
+=item * snippet
+
+Maintains a reference to the snippet that this cursor is iterating over.
+
+=item * has_prev
+
+Returns true/false depending on whether the cursor can move to a previous
+tab stop.
+
+=item * prev
+
+Moves the cursor to the previous tab stop and returns that tab stop.
+You can only iterate one element off the end of the underlying set of
+tab stops.
+
+=item * has_next
+
+Returns true/false depending on whether the cursor can move to a
+subsequent tab stop.
+
+=item * next
+
+Moves the cursor to the next tab stop and returns that tab stop.  You can
+only iterate one element off the end of the underlying set of tab stops.
+
+=item * current
+
+Returns the tab stop the cursor is currently pointing at.  When the cursor
+is first created, this method will always return C<undef> until C<next>
+has been called at least once.
+
+=item * current_position
+
+Returns an ArrayRef reflecting the line/column position relative to
+the beginning of the snippet.  Both numbers are zero-based so a tab
+stop starting on the first line, first character would return a value
+of C<[0,0]>.
+
+=item * current_char_position
+
+Returns an integer reflecting the current cursor position where 0 is the 
+first character of the snippet and each character is counted up until
+the current position of the cursor.
+
+=item * is_terminal
+
+Returns true if this tab stop is a "terminal" tab stop (i.e. once the
+user iterates to this tab stop, the iterator should be restored and
+normal editing should resume).
+
+=back
+
+=head1 AUTHOR
+
+  Brian Phillips <bphillips@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Brian Phillips.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
